@@ -1,6 +1,6 @@
-package Pcore::Firebird v0.5.2;
+package Pcore::Firebird v1.0.0;
 
-use Pcore -dist, -class;
+use Pcore -dist;
 
 1;
 __END__
@@ -16,16 +16,18 @@ Pcore::Firebird
 
 =head1 DESCRIPTION
 
+=head1 ATTRIBUTES
+
+=head1 METHODS
+
 =head1 SEE ALSO
 
 =head1 AUTHOR
 
-zdm <zdm@cpan.org>
-
-=head1 CONTRIBUTORS
+zdm <zdm@softvisio.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by zdm.
+This software is copyright (c) 2020 by zdm.
 
 =cut
